@@ -31,7 +31,6 @@ import org.apache.catalina.LifecycleState;
 import org.apache.catalina.Session;
 import org.apache.catalina.ha.ClusterManager;
 import org.apache.catalina.ha.ClusterMessage;
-import org.apache.catalina.session.ManagerBase;
 import org.apache.catalina.tribes.Channel;
 import org.apache.catalina.tribes.Member;
 import org.apache.catalina.tribes.io.ReplicationStream;
@@ -87,25 +86,25 @@ public class DeltaManager extends ClusterManagerBase {
 
     // -------------------------------------------------------- stats attributes
 
-    private long sessionReplaceCounter = 0;
-    private long counterReceive_EVT_GET_ALL_SESSIONS = 0;
-    private long counterReceive_EVT_ALL_SESSION_DATA = 0;
-    private long counterReceive_EVT_SESSION_CREATED = 0;
-    private long counterReceive_EVT_SESSION_EXPIRED = 0;
-    private long counterReceive_EVT_SESSION_ACCESSED = 0;
-    private long counterReceive_EVT_SESSION_DELTA = 0;
-    private int counterReceive_EVT_ALL_SESSION_TRANSFERCOMPLETE = 0;
-    private long counterReceive_EVT_CHANGE_SESSION_ID = 0;
-    private long counterReceive_EVT_ALL_SESSION_NOCONTEXTMANAGER = 0;
-    private long counterSend_EVT_GET_ALL_SESSIONS = 0;
-    private long counterSend_EVT_ALL_SESSION_DATA = 0;
-    private long counterSend_EVT_SESSION_CREATED = 0;
-    private long counterSend_EVT_SESSION_DELTA = 0;
-    private long counterSend_EVT_SESSION_ACCESSED = 0;
-    private long counterSend_EVT_SESSION_EXPIRED = 0;
-    private int counterSend_EVT_ALL_SESSION_TRANSFERCOMPLETE = 0;
-    private long counterSend_EVT_CHANGE_SESSION_ID = 0;
-    private int counterNoStateTransferred = 0;
+    private volatile long sessionReplaceCounter = 0;
+    private volatile long counterReceive_EVT_GET_ALL_SESSIONS = 0;
+    private volatile long counterReceive_EVT_ALL_SESSION_DATA = 0;
+    private volatile long counterReceive_EVT_SESSION_CREATED = 0;
+    private volatile long counterReceive_EVT_SESSION_EXPIRED = 0;
+    private volatile long counterReceive_EVT_SESSION_ACCESSED = 0;
+    private volatile long counterReceive_EVT_SESSION_DELTA = 0;
+    private volatile int counterReceive_EVT_ALL_SESSION_TRANSFERCOMPLETE = 0;
+    private volatile long counterReceive_EVT_CHANGE_SESSION_ID = 0;
+    private volatile long counterReceive_EVT_ALL_SESSION_NOCONTEXTMANAGER = 0;
+    private volatile long counterSend_EVT_GET_ALL_SESSIONS = 0;
+    private volatile long counterSend_EVT_ALL_SESSION_DATA = 0;
+    private volatile long counterSend_EVT_SESSION_CREATED = 0;
+    private volatile long counterSend_EVT_SESSION_DELTA = 0;
+    private volatile long counterSend_EVT_SESSION_ACCESSED = 0;
+    private volatile long counterSend_EVT_SESSION_EXPIRED = 0;
+    private volatile int counterSend_EVT_ALL_SESSION_TRANSFERCOMPLETE = 0;
+    private volatile long counterSend_EVT_CHANGE_SESSION_ID = 0;
+    private volatile int counterNoStateTransferred = 0;
 
 
     // ------------------------------------------------------------- Constructor
@@ -245,14 +244,6 @@ public class DeltaManager extends ClusterManagerBase {
         return counterReceive_EVT_ALL_SESSION_NOCONTEXTMANAGER;
     }
 
-    /**
-     * @return Returns the processingTime.
-     */
-    @Override
-    public long getProcessingTime() {
-        return processingTime;
-    }
-
     /**
      * @return Returns the sessionReplaceCounter.
      */
@@ -278,7 +269,9 @@ public class DeltaManager extends ClusterManagerBase {
     }
 
     public int getReceivedQueueSize() {
-        return receivedMessageQueue.size();
+        synchronized (receivedMessageQueue) {
+            return receivedMessageQueue.size();
+        }
     }
 
     /**
@@ -1089,13 +1082,13 @@ public class DeltaManager extends ClusterManagerBase {
         expiredSessions.set(0);
         synchronized (sessionCreationTiming) {
             sessionCreationTiming.clear();
-            while (sessionCreationTiming.size() < ManagerBase.TIMING_STATS_CACHE_SIZE) {
+            while (sessionCreationTiming.size() < TIMING_STATS_CACHE_SIZE) {
                 sessionCreationTiming.add(null);
             }
         }
         synchronized (sessionExpirationTiming) {
             sessionExpirationTiming.clear();
-            while (sessionExpirationTiming.size() < ManagerBase.TIMING_STATS_CACHE_SIZE) {
+            while (sessionExpirationTiming.size() < TIMING_STATS_CACHE_SIZE) {
                 sessionExpirationTiming.add(null);
             }
         }
